==> haskell-bitarray-0.0.1.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bitarray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bitarray
version:              0.0.1.1
visibility:           public
id:                   bitarray-0.0.1.1-6sAY8zRybbE5jehZt5ylT3
key:                  bitarray-0.0.1.1-6sAY8zRybbE5jehZt5ylT3
license:              BSD-3-Clause
copyright:            (c) 2009 Balazs Komuves
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Mutable and immutable bit arrays
description:          Mutable and immutable bit arrays.
category:             Data
abi:                  e238ca39c0803d404e57bf68e5f44fc7
exposed:              True
exposed-modules:      Data.BitArray Data.BitArray.IO Data.BitArray.ST
hidden-modules:       Data.BitArray.Immutable
import-dirs:          /usr/lib/ghc-8.8.3/site-local/bitarray-0.0.1.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/bitarray-0.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/bitarray-0.0.1.1
hs-libraries:         HSbitarray-0.0.1.1-6sAY8zRybbE5jehZt5ylT3
depends:              array-0.5.4.0 base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-bitarray/html/bitarray.haddock
haddock-html:         /usr/share/doc/haskell-bitarray/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bitarray-0.0.1.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bitarray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bitarray
version:              0.0.1.1
visibility:           public
id:                   bitarray-0.0.1.1-CyZ7NpHarND7xkmvyY2Ia9
key:                  bitarray-0.0.1.1-CyZ7NpHarND7xkmvyY2Ia9
license:              BSD-3-Clause
copyright:            (c) 2009 Balazs Komuves
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Mutable and immutable bit arrays
description:          Mutable and immutable bit arrays.
category:             Data
abi:                  dbc3a010777b129df892e3a9267a8a15
exposed:              True
exposed-modules:      Data.BitArray Data.BitArray.IO Data.BitArray.ST
hidden-modules:       Data.BitArray.Immutable
import-dirs:          /usr/lib/ghc-8.10.1/site-local/bitarray-0.0.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/bitarray-0.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/bitarray-0.0.1.1
hs-libraries:         HSbitarray-0.0.1.1-CyZ7NpHarND7xkmvyY2Ia9
depends:              array-0.5.4.0 base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-bitarray/html/bitarray.haddock
haddock-html:         /usr/share/doc/haskell-bitarray/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
